@@ -7,14 +7,15 @@ use Carp;
 
 require Exporter;
 use AutoLoader;
-use Socket qw( AF_INET );
-use Socket6 qw( inet_ntop inet_pton AF_INET6 );
+use if $] <  5.014000, Socket  => qw(inet_aton AF_INET);
+use if $] <  5.014000, Socket6 => qw(inet_ntop inet_pton AF_INET6);
+use if $] >= 5.014000, Socket  => qw(inet_ntop inet_pton inet_aton AF_INET6 AF_INET);
 use Net::NfDump::Fields;
 use threads;
 
 our @ISA = qw(Exporter);
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 # XXX
 # Items to export into callers namespace by default. Note: do not export
@@ -73,7 +74,7 @@ XSLoader::load('Net::NfDump', $VERSION);
 
 =head1 NAME
 
-Net::NfDump - Perl API for manipulating with nfdump files
+Net::NfDump - Perl API for manipulating with nfdump files based on libnf.net library 
 
 =head1 SYNOPSIS
 
@@ -864,12 +865,12 @@ sub txt2ip ($) {
 	}
 
 	if (index($addr, ':') != -1) {
-		$type = AF_INET6;
+    	return inet_pton(AF_INET6, $addr);
 	} else {
-		$type = AF_INET;
+		# ubuntu have buggy implementation of inet_pton for IPv4 
+    	return inet_aton($addr);
 	}
 
-    return inet_pton($type, $addr);
 }
 
 =pod
