@@ -29,7 +29,7 @@ typedef struct hash_table_s {
 	void * callback_data;		/* data tructure handled when called callback */
 	int numbuckets;				/* number of allocated buckets */
 	char ** buckets;
-//	char * entrypoint;
+	char * entrypoint;			/* entry point into linked list of elements */
 	unsigned long numentries; 
 //	unsigned long read_index; 
 	
@@ -51,10 +51,13 @@ hash_table_t * hash_table_init(hash_table_t *t, int numbuckets,
             hash_table_sort_callback_t scb,
             void *callback_data);
 
-int hash_table_fetch(hash_table_t *t, unsigned long index, char **pkey, char **pval);
+char * hash_table_first(hash_table_t *t);
+char * hash_table_next(hash_table_t *t, char *prow);
+void hash_table_fetch(hash_table_t *t, char *prow, char **pkey, char **pval);
 void hash_table_entry_len(hash_table_t *t, int keylen, int vallen);
 char * hash_table_insert(hash_table_t *t, char *key, char *val);
 int hash_table_sort_callback(char *prow1, char *prow2, void *p);
+void hash_table_link(hash_table_t *t);
 int hash_table_sort(hash_table_t *t);
 hash_table_t * hash_table_merge(hash_table_t *td, hash_table_t *ts);
 void hash_table_free(hash_table_t *t);
